@@ -141,9 +141,9 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         # prompt_date = prompt_time.date()
 
         if df_logs_combined.shape[0] == 0:
-            phone_lock = np.nan
-            last_usage = np.nan
-            closest_time = np.nan
+            phone_lock ="NF"
+            last_usage = "NF"
+            closest_time = "NF"
         else:
             subset_time_series = df_logs_combined["EVENT_TIME_DATETIME"]
 
@@ -162,21 +162,21 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
                         phone_lock = "Phone Locked"
                         last_usage = calculate_duration(prompt_time, closest_time)
                     else:
-                        phone_lock = np.nan
-                        last_usage = np.nan
+                        phone_lock = "NF"
+                        last_usage = "NF"
                 else:
                     if phone_event == "KEYGUARD_HIDDEN":
                         phone_lock = "Phone Locked"
-                        last_usage = np.nan
+                        last_usage = "NF"
                     elif phone_event == "KEYGUARD_SHOWN":
                         phone_lock = "Phone Unlocked"
                         last_usage = 0
                     else:
-                        phone_lock = np.nan
-                        last_usage = np.nan
+                        phone_lock = "NF"
+                        last_usage = "NF"
             else:
-                phone_lock = np.nan
-                last_usage = np.nan
+                phone_lock = "NF"
+                last_usage = "NF"
 
             # print("==   {}".format(phone_lock))
 
@@ -185,7 +185,7 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         matched_last_usage_list.append(last_usage)
 
 
-    return matched_phone_lock_list, matched_last_usage_list
+    return matched_phone_lock_list, matched_last_usage_list, matched_time_list
 
 
 def transform(phone_lock_column):
