@@ -65,10 +65,10 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
     info_dict = utils.load_participant_study_info.execute(intermediate_participant_path, output_dir_path)
 
     # - feature 1: Day of the week
-    feature1 = feature_engineering_ema.day_of_the_week.create_column(df_prompt['Prompt_Local_DateTime'], print_stats)
+    feature1 = feature_engineering_ema.day_of_the_week.create_column(df_prompt['Actual_Prompt_Local_DateTime'], print_stats)
     feature_df['DAY_OF_THE_WEEK'] = feature1
     # - feature 2: Time of the day
-    feature2 = feature_engineering_ema.time_of_the_day.create_column(df_prompt['Prompt_Local_DateTime'], print_stats)
+    feature2 = feature_engineering_ema.time_of_the_day.create_column(df_prompt['Actual_Prompt_Local_DateTime'], print_stats)
     feature_df['TIME_OF_THE_DAY'] = feature2
     # - feature 3: Days in the study
     feature3 = feature_engineering_ema.days_in_study.create_column(df_prompt, info_dict, print_stats)
@@ -76,13 +76,13 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
 
     # - feature 4: battery level
     feature5, feature6, match_time_battery = feature_engineering_ema.battery_level.create_column(
-        df_prompt['Prompt_Local_DateTime'], intermediate_participant_path, date_in_study)
+        df_prompt['Actual_Prompt_Local_DateTime'], intermediate_participant_path, date_in_study)
     feature_df['BATTERY_LEVEL'] = feature5
     feature_df['CHARGING_STATUS'] = feature6
     feature_df['match_time_battery'] = match_time_battery
 
     # - feature 5: GPS location
-    feature7, match_time_location = feature_engineering_ema.location.create_column(df_prompt['Prompt_Local_DateTime'],
+    feature7, match_time_location = feature_engineering_ema.location.create_column(df_prompt['Actual_Prompt_Local_DateTime'],
                                                                                    intermediate_participant_path,
                                                                                    date_in_study, decryption_password)
     feature_df['LOCATION'] = feature7
@@ -94,12 +94,12 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
 
     # - feature 7: Screen Status
     feature9, match_time_screen = feature_engineering_ema.screen_status.create_column(
-        df_prompt['Prompt_Local_DateTime'], intermediate_participant_path, date_in_study)
+        df_prompt['Actual_Prompt_Local_DateTime'], intermediate_participant_path, date_in_study)
     feature_df['SCREEN_STATUS'] = feature9
     feature_df['match_time_screen'] = match_time_screen
 
     # - feature 10&11: wake and sleep hour
-    feature10, feature11 = feature_engineering_ema.waking_hours.create_column(df_prompt['Prompt_Local_DateTime'],
+    feature10, feature11 = feature_engineering_ema.waking_hours.create_column(df_prompt['Actual_Prompt_Local_DateTime'],
                                                                               intermediate_participant_path,
                                                                               date_in_study)
     feature_df['WAKE_TIME'] = feature10
@@ -107,7 +107,7 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
 
     # - feature 12: Phone lock status
     feature12, feature13, match_time_lock = feature_engineering_ema.phone_lock.create_column(
-        df_prompt['Prompt_Local_DateTime'], intermediate_participant_path, date_in_study)
+        df_prompt['Actual_Prompt_Local_DateTime'], intermediate_participant_path, date_in_study)
     feature_df['PHONE_LOCK'] = feature12
     feature_df['LAST_USAGE_DURATION'] = feature13
     feature_df['match_time_lock'] = match_time_lock
@@ -120,9 +120,11 @@ def compute_features_phone(intermediate_participant_path, output_dir_path, date_
     feature_df['PROXIMITY_TO_SLEEP_TIME'] = feature16
 
     # - feature 14: MIMS Summary
-    df_mims = feature_engineering_ema.mims_summary.create_column(df_prompt['Prompt_Local_DateTime'],
+    mims_summary_df, readings_df, start_time_df = feature_engineering_ema.mims_summary.create_column(df_prompt['Actual_Prompt_Local_DateTime'],
                                                                  intermediate_participant_path, date_in_study)
-    feature_df = pd.concat([feature_df, df_mims], axis=1)
+    feature_df = pd.concat([feature_df, mims_summary_df], axis=1)
+    feature_df = pd.concat([feature_df, readings_df], axis=1)
+    feature_df = pd.concat([feature_df, start_time_df], axis=1)
 
 
     # save
